summaryrefslogtreecommitdiffstats
path: root/korn/dockeditem.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/dockeditem.h')
-rw-r--r--korn/dockeditem.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/korn/dockeditem.h b/korn/dockeditem.h
index 13cce3af..a80c1787 100644
--- a/korn/dockeditem.h
+++ b/korn/dockeditem.h
@@ -36,13 +36,14 @@ class TQPixmap;
*/
class DockedItem : public BoxContainerItem
{ Q_OBJECT
+ TQ_OBJECT
public:
/**
* This contructor gives all it parameters to its parents.
* @param parant The parent window
* @param name The name of the QObject's parents.
*/
- DockedItem( TQWidget * parent = 0, const char * name = 0 );
+ DockedItem( TQWidget * tqparent = 0, const char * name = 0 );
/**
* Empty destructor; does nothing at the moment
*/
@@ -54,10 +55,10 @@ public:
virtual void showBox();
/**
* This functions reads the config. It used the parent
* version for the main things, but it is possible to
* add some configurations over here.
- * @param config The KConfig-instance which tqcontains the settings of this tray-item.
+ * @param config The KConfig-instance which contains the settings of this tray-item.
* @param index The index of the box in the configuration file
*/
virtual void readConfig( KConfig* config, const int index );
@@ -36,13 +36,14 @@ class TQPixmap;
public:
/**
- * This contructor gives all it parameters to its parents.
- * @param parant The parent window
- * @param name The name of the QObject's parents.
+ * This contructor gives all it parameters to its tqparents.
+ * @param parant The tqparent window
+ * @param name The name of the TQObject's tqparents.
*/
@@ -54,10 +55,10 @@ public:
virtual void showBox();
/**
- * This functions reads the config. It used the parent
+ * This functions reads the config. It used the tqparent
* version for the main things, but it is possible to
* add some configurations over here.